@@ -164,13 +164,14 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
         date_of_birth: Option<chrono::DateTime::<chrono::Utc>>,
         place_of_birth: Option<String>,
         polity_name: Option<String>,
+        specialism: Option<String>,
         sorts: Option<&Vec<models::StudentSortCriteria>>,
         offset: Option<i32>,
         count: Option<i32>,
         context: &C) -> Result<GetStudentsResponse, ApiError>
     {
         let context = context.clone();
-        info!("get_students({:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}) - X-Span-ID: {:?}", name, email, phone, undergraduate_school, date_of_birth, place_of_birth, polity_name, sorts, offset, count, context.get().0.clone());
+        info!("get_students({:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}) - X-Span-ID: {:?}", name, email, phone, undergraduate_school, date_of_birth, place_of_birth, polity_name, specialism, sorts, offset, count, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
