@@ -331,7 +331,7 @@ impl std::str::FromStr for StudentSortCriteria {
 /// Student View
 #[derive(Debug, Clone, PartialEq, serde::Serialize, serde::Deserialize)]
 #[cfg_attr(feature = "conversion", derive(frunk::LabelledGeneric))]
-#[serde(rename = "student")]
+#[serde(rename = "student-view")]
 pub struct StudentView {
     #[serde(rename = "id")]
     #[serde(skip_serializing_if="Option::is_none")]
@@ -625,8 +625,7 @@ impl std::convert::TryFrom<hyper::header::HeaderValue> for header::IntoHeaderVal
 #[cfg_attr(feature = "conversion", derive(frunk::LabelledGeneric))]
 pub struct StudentViewCollection {
     #[serde(rename = "students")]
-    #[serde(skip_serializing_if="Option::is_none")]
-    pub students: Option<Vec<models::StudentView>>,
+    pub students: Vec<models::StudentView>,
 
     #[serde(rename = "hasMore")]
     #[serde(skip_serializing_if="Option::is_none")]
@@ -639,9 +638,9 @@ pub struct StudentViewCollection {
 }
 
 impl StudentViewCollection {
-    pub fn new() -> StudentViewCollection {
+    pub fn new(students: Vec<models::StudentView>, ) -> StudentViewCollection {
         StudentViewCollection {
-            students: None,
+            students: students,
             has_more: None,
             total: None,
         }
@@ -714,7 +713,7 @@ impl std::str::FromStr for StudentViewCollection {
 
         // Use the intermediate representation to return the struct
         std::result::Result::Ok(StudentViewCollection {
-            students: intermediate_rep.students.into_iter().next(),
+            students: intermediate_rep.students.into_iter().next().ok_or("students missing in StudentViewCollection".to_string())?,
             has_more: intermediate_rep.has_more.into_iter().next(),
             total: intermediate_rep.total.into_iter().next(),
         })
